#############################################################################################
#   
#   REPRESENTACION ESPACIAL Y MAPAS 
#    
#   por
#
#   Rodrigo Rodrigues-Silveira
#   rodrodr@gmail.com
#   
#   SEGUNDO CAPITULO - EJEMPLOS
#
#   Este codigo esta destinado a ser utilizado en el paquete estadistico R
#   R version 3.0.1 (Windows). Ademas, para que funcione, todos los archivos denominados
#   "material auxiliar" deben estar presentes en la carpeta:
#   C:\\CIS\\Material Auxiliar\\
#   En el caso de que el usuario desee utilizar otra carpeta, debe alterar el 
#   contenido de la variable "cdt" - carpeta de trabajo, mas abajo.
#   
#   Ultima revision: 19 de julio de 2013.
###########################################################################################



# SECCION 2.3. - GEORREFERENCIACION DE DATOS NO-ESPACIALES


## Ejemplo de problemas de agregacion (figura 2.1)

# Abre los archivos de mapa
br <- readShapeSpatial("Municipios.shp")
uf <- readShapeSpatial("Estados.shp")
reg <- readShapeSpatial("Regiones.shp")


# Figura 2.1a - Regiones
par(mar=c(0,0,0,0))
franjas <- round(quantile(reg$ts_urb, probs=seq(0,1,0.25),na.rm=T), 1)
pal <- brewer.pal(5, "Greys") 
reg$col <- c(pal[4],pal[1],pal[2],pal[5],pal[3])
plot(reg,col=reg$col)
legend("bottomright", legend = franjas, fill=pal, cex=0.8, pt.cex=0.3, bty="n")


# Figura 2.1b - Estados
par(mar=c(0,0,0,0))
franjas <- round(quantile(uf$ts_urb, probs=seq(0,1,0.25),na.rm=T), 1)
pal <- brewer.pal(4, "Greys") 
colores <- pal[findInterval(uf$ts_urb,franjas, all.inside=T)]
plot(uf,col=colores)
plot(reg, lwd=2, add=T)
legend("bottomright", legend = leglabs(franjas, "<",">"), fill=pal, cex=0.8, pt.cex=0.3, bty="n")



# Figura 2.1c - Municipios

par(mar=c(0,0,0,0))
franjas <- round(quantile(br$ts_urb, probs=seq(0,1,0.25),na.rm=T), 1)
pal <- brewer.pal(4, "Greys") 
colores <- pal[findInterval(br$ts_urb,franjas, all.inside=T)]
plot(br,col=colores, border="transparent")
plot(uf, add=T, lwd=0.4)
plot(reg, lwd=1, add=T)
legend("bottomright", legend = leglabs(franjas, "<",">"), fill=pal, cex=0.8, pt.cex=0.3, bty="n")




##############################################################################################
########################## PASO 1: ABRIR UNA BASE DE DATOS en R ##############################
##############################################################################################

# Establece la carpeta de trabajo (donde se encuentran todos los archivos de ejemplos)
cdt <- c("C:/CIS/Material Auxiliar/Shapes/")
setwd(cdt)

# Abre la base de datos en el formato .CSV

# La funcion read.csv(.) abre el archivo "datos_ccaa.csv" que se encuentra
# en la carpeta "Material Auxiliar\Shapes\" y crea un objeto de tipo base de datos
# llamado datos.csv, que sera utilizado para todas las operaciones
# Parametros:
#       header=TRUE - lee los nombres de las variables en la primera linea.
#       sep=";" - el separador entre variables es el punto y coma.
# Resultado:
#       Se genera un objeto de tipo base de datos (data.frame) denominando datos.csv
#       con todas las informaciones contenidas en el archivo
datos.csv <- read.csv("datos_ccaa.csv", header=TRUE, sep=";")


# Abre la base de dato en el formato .XLS

# Carga el paquete RODBC, necesario para conectar con el Excel
library(RODBC)

# Abre el archivo Excel elegido
conexion <- odbcConnectExcel2007("datos_ccaa.xls")

# Lista el nombre de todas las hojas de la panilla de datos
sqlTables(conexion)

# Resultado
#                                              TABLE_CAT TABLE_SCHEM TABLE_NAME
# 1 C:\\CIS\\Material Auxiliar\\Shapes\\datos_ccaa        <NA>     Hoja1$
# 2 C:\\CIS\\Material Auxiliar\\Shapes\\datos_ccaa        <NA>     Hoja2$
# 3 C:\\CIS\\Material Auxiliar\\Shapes\\datos_ccaa        <NA>     Hoja3$


# Lee los datos de la primera hoja de la planilla "Hoja 1"
#(o cualquier otra hoja elegida) en el archivo de base de datos "datos.xls"
datos.xls <- sqlFetch(conexion, "Hoja1")

# Cierra todas las conexiones ODBC - para evitar el consumo innecesario de memoria
odbcCloseAll()

# Archivos DBF y provenientes de paquetes estadisticos

# Carga el paquete foreign (necesario para abrir archivos del SPSS y otros formatos)
library(foreign)

# DBF - formato DBF
datos.dbf <- read.dbf("datos_ccaa.dbf")

# SPSS - formato SAV
datos.spss <- data.frame(read.spss("datos_ccaa.sav"))

# STATA - formato DTA
datos.stata <- read.dta("datos_ccaa.dta")

# Obs.: El R permite remover los objetos que no seran utilizados de la memoria.
#       Este procedimiento resulta particularmente util para accelerar el
#       procesamiento de datos.

# Funcion rm(.) - remueve un objeto de la memoria
rm(datos.xls)
rm(datos.dbf)
rm(datos.spss)
rm(datos.stata)

# OBS: Para remover TODOS los objetos de la memoria de un golpe basta utilizar la funcion:
rm(list=ls())

##############################################################################################
###### PASO 2: Analisis de consistencia y tratamiento de casos perdidos (Missing) ############ 
##############################################################################################

# A) ANALISIS DE DATOS

# vuelve a abrir la base de dados .csv
datos.csv <- read.csv("datos_ccaa.csv", header=TRUE, sep=";")


# Obtiene las estadisticas descriptivas de la base de datos
summary(datos.csv)

# Examen de casos extremos - Elecciones Municipales de Espana 2011

# La funcion attach(.) hace con que no sea necesario utilizar la expresion 
# datos.csv$ antes del nombre de cualquier variable (especialmente util 
# cuando existe solamente uno objeto de tipo data.frame)
attach(datos.csv)

# genera un objeto de datos solamente con el porcentaje de votos en las
# elecciones municipales espa?olas en 2011 para el PP, PSOE y Otros partidos
# La funcion cbind(.) permite combinar distintos vectores en un solo objeto de tipo data.frame
votos <-  cbind(ppmunper11, psoemunper11, otrosmunper11)

# Genera el boxplot segmentado por cada uno de esos tres grupos

# Estabelece as margens para o grafico
par(mar=c(4,4,2,0.4))

# Parametros:
#         votos - conjunto de datos a ser representado en el Boxplot
#         names = nombres de cada una de las variables a ser repreentadas
#         xlab = titulo del eje X
#         ylab = titulo del eje Y
boxp <- boxplot(votos, names=c("PP","PSOE","Otros"), xlab="Partidos", ylab="% de voto") 

# Vuelve a hacer necesaria la referencia al objeto base de datos para identificar
# las variables (para poder trabajar con mas de un data.frame)
detach(datos.csv)


# B) IDENTIFICACION DE CASOS PERDIDOS

# Figura 2.3

# Abre los archivos de mapa
br <- readShapeSpatial("Municipios.shp")
uf <- readShapeSpatial("Estados.shp")
reg <- readShapeSpatial("Regiones.shp")

# Abre la base de datos con las informaciones conteniendo los casos perdidos
mis <- read.csv("datos_muni_br.csv", header=T, sep=";")

# Asocia las informaciones con el archivo espacial
row.names(mis) <- mis$GEOCODIG_M
spChFIDs(br) <- br$GEOCODIG_M
bra <- SpatialPolygonsDataFrame(br, mis, match.ID=T)

# Genera un color gris para los casos perdidos
bra$col <- "white"
bra$col[is.na(bra$rt_md)] <- "grey40"

# Dibuja los resultados para los municipios
par(mar=rep(0,4))
plot(bra, col=bra$col, border=F)
plot(uf, add=T)
plot(reg, lwd=2, add=T)
legend("bottomleft",legend=c("Perdidos","Otros"), fill=c("grey40","white"), bty="n", cex=1)


# Repite los mismos resultados, pero ahora para determinar el percentual de municipios con valor perdido en cada estado
bra <- data.frame(bra)
bra$ct <- 1
bra$mis <- 0
bra$mis[is.na(bra$rt_md)] <- 1
ufmis <- aggregate(bra[,15:16], by=list(uf=bra$uf), sum)
ufmis$per_mis <- round(ufmis$mis/ufmis$ct*100,1)

row.names(ufmis) <-  ufmis$uf
spChFIDs(uf) <- uf$uf
uf <- SpatialPolygonsDataFrame(uf, ufmis, match.ID=T)


par(mar=rep(0,4))
pal <- brewer.pal(4, "Greys") 
franjas <- c(0,5,10,30,100)
colores <- pal[findInterval(uf$per_mis,franjas, all.inside=T)]
plot(uf,col=colores,lwd=0.4)
plot(reg, lwd=2, add=T)
legend("bottomleft", legend = leglabs(franjas, "<",">"), fill=pal, cex=0.8, pt.cex=0.3, bty="n", title="(%) Perdidos")







# Abre el archivo de datos que contiene la renta media de los municipios brasilenos
db_muni <- read.csv("datos_muni_br.csv", header=TRUE, sep=";")

# La funcion is.na(.) genera una variable logica (verdadero/falso) para identificar los casos perdidos de la variable renta media
perdidos <- is.na(db_muni$rt_md)

# Convierte la variable logica en una dummy con valores 1 para verdadero y 0 para falso
perdidos <- as.integer(perdidos)

# Obs.: Una manera mas directa de hacer el mismo procedimiento seria:
perdidos <- as.integer(is.na(db_muni$rt_md))

# Agrega los casos perdidos por estado. Eso se hace en dos pasos: primero la funcion 
# aggregate(.) agrega los resultados por la lista definida en "by=" y segun la funcion
# "FUN=" elegida. Luego, los resultados (en formato de lista), son convertidos en una base de datos
# por medio de la funcion data.frame(.)
perd_estado <- data.frame(aggregate(perdidos, by=list(db_muni$uf), FUN=sum))

# Calcula el porcentaje de los casos perdidos por total de casos. La funcion length(.) determina el tamano o el numero de elementos en un determinado objeto:
casos <- data.frame(aggregate(perdidos, by=list(db_muni$uf), FUN=length))
est_perd_per  <- round(perd_estado$x / casos$x *100,1)

# Genera las estadisticas descriptivas para los casos perdidos por estado
summary(est_perd_per)

# Los resultados revelan el mismo patron presentado por la figura 2.3


# C) IDENTIFICACION VISUAL DE CASOS PERDIDOS - EL PAQUETE VIM

# Carga el paquete VIM a la memoria
library(VIM)

# La funcion aggr(.) genera los graficos de casos perdidos para la base de datos db_muni
aggr(db_muni)


# Divide la ventana de graficos para que se puedan representar cuatro en paralelo (2x2)
par(mfrow=c(2,2))

# Define los margenes para los graficos
par(mar=c(4,4,4,0.1))

# La funcion spineMiss(.) Genera los graficos de barra para el cruce de las cuatro variables
spineMiss(db_muni[,c("idh","pfun_fed")])
spineMiss(db_muni[,c("ppobres","pfun_fed")])
spineMiss(db_muni[,c("tx_urb","pfun_fed")])
spineMiss(db_muni[,c("rt_md","pfun_fed")])

# Regresa a la configuracion inicial de un grafico por ventana
par(mfrow=c(1,1))


# D) TRATAMIENTO DE CASOS PERDIDOS (MISSING) - IMPUTACION DE DATOS

# Imputacion por el metodo de exclusion (listwise deletion). Las funciones na.omit(.) 
# y na.exclude(.) excluyen todos los casos que contengan NA en cualquier una de sus variables
na_data <- na.omit(db_muni)

# Carga la biblioteca Hmisc que permite la imputacion de los valores por la media y la imputacion multiple
library(Hmisc)

# Imputacion por valor unico (media)
med_data <- impute(db_muni, FUN=mean)

# Imputacion por el metodo HOT-DECK (puede tardar unos segundos) 
hot_data <- hotdeck(db_muni)

# Imputacion por los K vecinos mas cercanos
knn_data <- kNN(db_muni)

# Lleva a cabo la imputacion a partir de un metodo de regresion robusta (en la que todas las variables sirven de predictores unas de las otras.
# Parametros:
#            formula = el simbolo ~ representa que las variables que vienen despues conectadas
#                      por la senal de adicion + se emplearan como predictoras unas de las 
#                      otras en el proceso de imputacion de valores perdidos
#            data= el nombre de la base de datos que contiene los casos perdidos
#            n.impute= numero de muestras aleatorias extraidas de la base de datos original
#                      que seran utilizadas para generar la imputacion
#            match= el criterio de seleccion de los valores mas cercanos entre si
#            x=TRUE genera un atributo X conteniendo los valores imputados finales
imp <- aregImpute(~rt_md+ppobres+pib_pct+tx_urb+idh+esp_2000+pfun_loc+ pfun_est+pfun_fed, data=db_muni, n.impute=10, match= "closest", x=TRUE)

# Convierte los resultados imputados en base de datos
multi_data <- data.frame(imp$x)

attach(db_muni)

# Anade los codigos de identificacion a los resultados imputados por la tecnica multiple
multi_data <- cbind(geocodig_m, ID, multi_data)

detach(db_muni)

# Retorna las estadisticas descriptivas para la variable renta media para cada una de las estrategias empleadas
summary(db_muni$rt_md)
summary(med_data$rt_md)
summary(na_data$rt_md)
summary(hot_data$rt_md)
summary(knn_data$rt_md)
summary(multi_data$rt_md)


##############################################################################################
############################# PASO 3: Agregacion de datos ####################################
##############################################################################################

# Como las variables son de porcentajes o tasas, el metodo de agregacion mas apropiado es la media. Por tanto, se agregaran los casos por la media de los municipios por estado.

# Elige solamente las variables que se desea agregar
agrega <- knn_data[3:13]

# Averigua los nombres de las variables de la nueva base de datos
names(agrega)

# Agrega los datos segun el estado - funcion aggregate(.)
# parametros: 
#             base de datos: agrega; 
#             by = lista de todos los estados, obtenida por la funcion list(.); 
#             FUN = funcion empleada para realizar la agregacion
agrega <- aggregate(agrega, by=list(uf=agrega$uf), FUN=mean) 

# El mismo procedimiento vale para agregar solamente una variable, como por ejemplo, el total de votos validos
idh_est <- aggregate(agrega$idh, by=list(uf=agrega$uf), FUN=mean)


##############################################################################################
######################## PASO 4: Fusion con los archivos Shape ###############################
##############################################################################################

# Carga el paquete Maptools que permite leer archivos de tipo Shape
library(maptools)

# Abre el archivo Shape para averiguar la fusion correcta de las variables

# La funcion readShapeSpatial(.) permite leer archivos de tipo Shape (formas de los mapas)
# en el interior del R a un objeto de tipo SpatialShape. 
# Parametros:
#             nombre - nombre del archivo shape a ser abierto (por ejemplo "ccaa.shp")
estados <- readShapeSpatial("Estados.shp")

# la funcion names(estados) lista todas las variables que pertenecen al archivo Shape
names(estados)

# Convierte los codigos a los oficiales utilizados por el IBGE
estados$ID_ <- estados$ID_/10000

# Genera nuevos nombres de identificacion para los estados 
estados <- spChFIDs(estados, as.character(estados$ID_))

# Establece los nombres del objeto agrega como el codigo de los estados
row.names(agrega) <- agrega$uf

# Lleva a cabo la fusion de los dos archivos
estadosA <- SpatialPolygonsDataFrame(estados, agrega, match.ID=TRUE)

# Inspecciona los resultados
View(estadosA)




#######################################################################################################
########################### FINAL DEL ARCHIVO DE EJEMPLOS - CAPITULO 2 ################################
#######################################################################################################