#############################################################################################
#   
#   REPRESENTACION ESPACIAL Y MAPAS 
#    
#   por
#
#   Rodrigo Rodrigues-Silveira
#   rodrodr@gmail.com
#   
#   TERCER CAPITULO - EJEMPLOS
#
#   Este codigo esta destinado a ser utilizado en el paquete estadistico R
#   R version 3.0.1 (Windows). Ademas, para que funcione, todos los archivos denominados
#   "material auxiliar" deben estar presentes en la carpeta:
#   C:\\CIS\\Material Auxiliar\\
#   En el caso de que el usuario desee utilizar otra carpeta, debe alterar el 
#   contenido de la variable "cdt" - carpeta de trabajo, mas abajo.
#   
#   Ultima revision: 19 de julio de 2013.
###########################################################################################


#######################################################################################################
###################### Abrir un archivo de mapas y generar una vista en el R ##########################
#######################################################################################################


# Establece la carpeta de trabajo (espacio donde estan ubicados los archivos auxiliares)
rm(list=ls())

cdt <- c("C:/CIS/Material Auxiliar/Shapes/")
setwd(cdt)

par(mar=rep(2,4))

# Abre el archivo de mapas de las provincias espanolas en el objeto "provs"
library(maptools)

# Modo A: simplemente con el nombre del archivo
ccaa <- readShapeSpatial("ccaa.shp")


# Modo B: completo

# Genera una variable con el tipo de proyeccion que sera utilizada en todo el capitulo
# En general las informaciones sobre la proyeccion de un mapa son suministradas
# por quienes lo construyeron. La mayor parte de los sitios web que disponibilizan
# los mapas tambien suministran la proyeccion. En caso negativo, los archivos con
# extension .prj contienen las proyecciones geograficas y muchas veces acompanan
# los archivos de tipo .shp . Los archivos de tipo .prj pueden abrirse utilizando el 
# bloc de notas o cualquier editor de texto.
proyeccion <- "+init=epsg:3035"

# Abrir los archivos de mapas en el R (funcion: readShapeSpatial)
# La funcion readShapeSpatial(.) permite leer archivos de tipo Shape (con las formas de los mapas)
# en el interior del R a un objeto de tipo SpatialShape. Los parametros son los siguientes:
# nombre - nombre del archivo shape a ser abierto (por ejemplo "ccaa.shp")
# proyeccion - tipo de proyeccion geografica, en el caso la contenida en la variable proyeccion
# IDvar - variable en el archivo dbf asociado al shp (con el mismo nombre) que identifica
#         cada unidad espacial de forma unica.
# repair = TRUE - valido para el caso de shapefiles generados por algunos programas que no
#                 son totalmente compatibles con el formato ESRI (estandar)
# force_ring = TRUE - el mismo que la opcion anterior, resuelve problemas de creacion en el
#                     archivo shape, en particular cierra poligonos que no han sido cerrados
#                     completamente.
ccaa <- readShapeSpatial("ccaa.shp", proj4string = CRS(proyeccion), IDvar = "SP_ID", repair=TRUE, force_ring=TRUE)

# Genera un mapa de las fronteras de las Comunidades Autonomas espanolas
plot(ccaa)


############## Fusion de los datos para las CCAA #####################################

# NOTA: Este procedimiento no resulta necesario si ya se ha llevado a cabo 
#       el ejercicio 6 del capitulo 2. 

# Fusiona los datos de datos_ccaa.csv
ccaa_dat <- read.csv("datos_ccaa.csv", header=T, sep=";")

# Cambia el codigo de la comunidad autonoma como el nombre de las lineas que identifican cada caso 
ccaa <- spChFIDs(ccaa, as.character(ccaa$CC_COD))

# Ordena los casos de la base de datos "agrega" segun el orden original de los poligonos en "estados"
ord <- match(row.names(ccaa), ccaa_dat$CC_COD)
ccaa_dat <- ccaa_dat[ord,]

# Cambia el nombre de las lineas para que sean iguales a los del objeto espacial ccaa
row.names(ccaa_dat) <- row.names(ccaa)

# Lleva a cabo la fusion de los dos archivos
ccaa <- spCbind(ccaa, ccaa_dat)

# Exhibe los resultados para inspeccion
View(ccaa)

########################################################################################


library(sp)

# Abre el archivo de mapa con las fronteras de las provincias espanolas
provs <- readShapeSpatial("provincias.shp")

# Genera el mapa de fronteras de las provincias a las CCAA y el parametro border="blue" define que deben ser azules
plot(provs, border="blue")

# El parametro add=TRUE vuelve a generar el mapa de las fronteras de las CCAA pero superpuestas a las de las provincias
plot(ccaa, add=TRUE)

# Abre el archivo de mapa con los puntos indicando la ubicacion de las capitales de provincia
caps <- readShapeSpatial("capitals.shp")

# Dibuja las capitales de las provincias espanolas (figura 3 - Puntos)
# en ROJO (col="red"), como circulos (pch=19) y
# con un tamano de los puntos relativamente grandes para visualizacion (cex=2) 
plot(caps, col = "red", pch=19, cex=0.6, add=TRUE)





#######################################################################################################
############################## Anadir elementos graficos a un mapa ####################################
#######################################################################################################


#################### GENERACION DEL UN MAPA COROPLETICO DE BASE ##################################

# Como ejemplo utilicenos la Espana continental
ccaacont <- ccaa[ccaa$NOMBRE_CCA!="Canarias",]

# Definir el tipo de fuente a ser utilizada (Times New Roman)
windowsFonts(times =windowsFont("Times New Roman"))

# Establece los parametros graficos basicos: tipo de fuente: times new roman, y margenes de la figura.
par(family="times")
par(mar=c(2,2,2,0.1))


# Paso 1: Define los puntos de quiebre de la variable de interes (ccaa$ppmunper11) de forma aleatoria.
franjas <- c(5.99, 40, 50, 65.16)

# Paso 2: Elige los colores a ser utilizados. 
colores <- c("white", "grey90","grey22")

# Paso 3: Genera el mapa de las CCAA segun la pertenencia de cada CA a uno de los intervalos elegidos.
#             La funcion findInterval(.) atribuye un color a cada CA cuyo valor para la variable 
#  ccaa$ppmunper11 se encuentre dentro de cada uno de los intervalos contenidos en "franjas". 
plot(ccaacont,col=colores[findInterval(ccaacont$ppmunper11, franjas, all.inside=TRUE)], axes=T)

# Para anadir ejes y la rejilla de paralelos y meridianos se debe tomar las siguientes opciones:
# 1 - anadir axes=T en la funcion plot() - dibuja los ejes con las coordinadas
plot(ccaacont,col=colores[findInterval(ccaacont$ppmunper11, franjas, all.inside=TRUE)], axes=T)

# 2 - utilizar la funcion grid() para generar  la rejilla de los paralelos y meridianos (lineas en forma de traceado)
grid(col="lightgray", lty=3)

# 3 - caso se desee manipular los ejes para incluir mas puntos:
# No es necesario, pero desable, anadir unas referencias menores de posicion (como 1 grado decimal) 
# para facilitar la localizacion de puntos en el mapa
library(Hmisc)
minor.tick(5,5)


########################### ANADIR TITULO AL GRAFICO #######################################


# La funcion title anade el titulo 
title(main="Mapa equilibrado", font.main=1, adj=0.5, cex.main=1.8)


################################# ANADIR LEYENDA #######################################

# La funcion leglabs, del paquete maptools, permite crear automaticamente franjas de valor para
# un mapa
# Los parametros basicos son:
#                         vec= variable con los intervalos a ser representados
#                         under= simbolo utilizado para valores inferiores a...
#                         over= simbolo utilizado para valores superiores a...
#                         between= simbolo utilizado para separar los valores de una categoria
leyenda <- leglabs(franjas, under="<",over=">", between="a")

# Funcion legend(.) - genera la leyenda segun los parametros definidos.
# Parametros:
#        coordinadas x/y - posicion del grafico en que se desea posicionar la leyenda. Podria ser tambien
#                 las coordinadas X,Y de un punto deseado por el investigador.
#         legend - variable con las franjas a ser representadas.
#         fill - colores que serviran para rellenar las casillas de cada intervalo.
#         title - titulo de la leyenda.
#         bty="n" - no dibuja una caja alrededor de la leyenda.
legend(x=-0.04949725, y=37.59354, legend = leyenda, fill = colores, title = "% Voto PP (2011)", bty="n")


################### ANADIR ESCALA GRÁFICA Y ROSA DE LOS VIENTOS ################################

# Obs: Acuerdese de que se puede utilizar la funcion locator(.)  para determinar la posicion 
# de cada uno de esos elementos en el mapa.
# locator()

# Carga en la memoria las funciones Cartograficas Auxiliares (en particular scalebar() )
source("carto_functions.R")

# Escala grafica de 500 kilometros (unit=1)
loc_escala <- c( -9.627544, 35.58579)
scalebar(loc_escala, 250, unit=1)

# Rosa de los vientos

# Definir el tipo de fuente a ser utilizada (Times New Roman)
windowsFonts(rosa =windowsFont("Webdings"))

# Dibuja la rosa de los vientos en el mapa
loc_seta <- c(-8.600512, 39.70281)
text(loc_seta[1],loc_seta[2], labels="l", family="rosa", cex=4)

# Redefine el tipo de fuente para el estandar y reduce los margenes a cero
par(family="")
par(mar=c(0,0,0,0.1))


####################### MAPA DESEQUILIBRADO ##################################################


par(mar=c(2,2,2,0.1))
plot(ccaacont,col=colores[findInterval(ccaacont$ppmunper11, franjas, all.inside=TRUE)], axes=T)

# Definir el tipo de fuente a ser utilizada (Broad)
windowsFonts(broad =windowsFont("Broadway"))

# La funcion title anade el titulo 
title(main="MAPA DESEQUILIBRADO",family="broad", font.main=2, adj=0, cex.main=0.6)

# Atribuye una otra fuente para la leyenda
windowsFonts(leg =windowsFont("Pristin"))
par(family="leg")

# Leyenda
legend("left", legend = leyenda, fill = colores, title = "% Voto PP (2011)", bty="n")


# Escala grafica

# Carga en la memoria las funciones Cartograficas Auxiliares (en particular scalebar() )
source("carto_functions.R")

# Escala grafica de 500 kilometros (unit=1)
loc_escala <- c( -9.627544, 35.58579)
scalebar(loc_escala, 250, unit=1)

# Rosa de los vientos

# Definir el tipo de fuente a ser utilizada (Times New Roman)
windowsFonts(rosa =windowsFont("Webdings"))

# Dibuja la rosa de los vientos en el mapa
loc_seta <- c(-8.71512, 37.50281)
text(loc_seta[1],loc_seta[2], labels="l", family="rosa", cex=4)

# Reestablece los parametros graficos anteriores
par(family="")
par(mar=c(0,0,0,0.1))

#######################################################################################################
############################### Clasificacion de datos - intervalos ###################################
#######################################################################################################


################## Mapa de variables categoricas - sin clasificacion  ##########################

# Figura 3.5 - mapa de las provincias clasificadas por Comunidad Autonoma

# Crea una lista ordenada de las CCAA contenidas en la variable COM del objeto Shape provs.
franjas <- sort(unique(provs$COM))

# Define una variable con 17 colores (uno para cada CA)
colores <- c("white","blue4","orange","green","red","gray","cyan","chocolate", "darkmagenta", "deeppink3", "gold2","indianred2", "lightgreen", "mediumpurple", "navajowhite", "brown", "darkgreen", "black")

# Genera el mapa, clasificando las provincias por color segunn la CA a que pertenece.
# La funcion findInterval(.) atribuye un color a cada provincia (provs$COM) un color especifico,
# segun la CA a que pertenece (contenida en la variable franjas)
plot(provs, col=colores[findInterval(provs$COM, franjas, all.inside=TRUE)], border = "black")




################## Clasificacion de datos utilizando el paquete classInt ##########################

# Abre los datos de las provincias
datos <- read.csv("prov_educacion.csv", header=TRUE, sep=";")
summary(datos$pibpct08)

# Fusiona con el archivo de provincias
provs <- spChFIDs(provs, as.character(provs$SP_ID))
row.names(datos) <- datos$ID_2
provs <- SpatialPolygonsDataFrame(provs, datos,match.ID=T)

# Selecciona solo las provincias de Espana continental
provs <- provs[provs$ccaa_nombre!="Las Palmas",]


# Carga el paquete classInt y calcula el tipo - intervalos iguales
library(classInt)
int <- classIntervals(provs$pibpct08, 4, "equal")
breaks <- round(int$brks)

# Numero igual de casos - cuantiles
int <- classIntervals(provs$pibpct08, 4, "quantile")
breaks <- round(int$brks)

# Cluster k-means
int <- classIntervals(provs$pibpct08, 4, "kmeans")
breaks <- round(int$brks)

# Natural breaks
int <- classIntervals(provs$pibpct08, 4, "jenks")
breaks <- round(int$brks)

# Desviacion estandar
int <- classIntervals(provs$pibpct08, 4, "sd")
breaks <- round(int$brks)


#######################################################################################
## Codigo utilizado para generar los dopPlots de la figura 3.6 ########################

install.packages("qualityTools")
library(qualityTools)
colores <- c("white", "grey90","grey50","grey22")
windowsFonts(times =windowsFont("Times New Roman"))
par(mar=c(4,0.1,0.1,1))
dotPlot(provs$pibpct08, pch=c(19,19,19,19,19), bty="n", group=findInterval(provs$pibpct08, breaks, all.inside=T), col=colores, axes=F, xlab="Desviacion Estandar", family="times")
axis(side=1, at=breaks, family="times")

#######################################################################################


########################################################################################
# Confeccion de los mapas de la figura 3.7

# (A) Elige los colores a ser utilizados (blanco, gris claro, gris intermedio, gris oscuro).
colores <- c("white", "grey90","grey50","grey22")

# OBS: En el caso de la DESVIACION ESTANDAR 
#        	Se recomienda el uso de una escala cromatica opuesta (o divergente):
#      		- colores frios para los valores por debajo de la media 
#      		- colores calientes para los valores por arriba de la media
colores <- c("steelblue2", "lightcyan","lightgoldenrod1","darkorange","firebrick3")

# (B) Relaciona cada caso a un color especifico por medio de la funcion findColours(.)
#  Parametros:
#		Int - objeto intervalo generado por la funcion ClassIntervals(.)
#		Colores - variable con los nombres de los colores deseados para las franjas.
col <- findColours(int, colores)

# (C) Define los titulos de las franjas a ser utilizadas en la leyenda (formateando los numeros)
leyenda <- leglabs(format(breaks, decimal.mark=",",big.mark="."), under="<", over=">", between="a")

# (D) Dibuja el mapa - Genera el mapa de las provincias segun su pertenencia a uno de los 
#       intervalos elegidos
plot(provs, col=col, border = "black")

# (E) Genera la leyenda
legend("bottomright", legend = leyenda, fill = colores, cex= 0.9, pt.cex = cex, title = "Desviacion Estandar", bty="n")


#######################################################################################################
#################################### El uso del color en mapas ########################################
#######################################################################################################


# Funcion colors(.) - lista el nombre de todos los 657 colores pre-programados en el R
colors()


######################### color unico ####################################################

# Funcion colorRampPalette(.) - genera una funcion (denominada col(.) ) que permite crear 
# una secuencia continua y progresiva de colores para todos los elementos de una determinada variable.
col <- colorRampPalette(c("white","blue4"))

# Genera una escala de seis gradaciones de color que va del blanco ("white") al azul oscuro 
# ("blue4")
colores <- col(6)

# Suministra la lista de colores generada en formato hexadecimal
colores

# Mapea la paleta de los colores generados sin borda y sin espacio entre las barras
barplot(rep(1,length(colores)), col=colores, border=NA, space=0, axes=FALSE)


######################### Tres colores ####################################################


col <- colorRampPalette(c("blue4","white","orangered2"))

# Genera una escala de seis gradaciones de color que va del blanco ("white") al azul oscuro 
# ("blue4")
colores <- col(7)

# Suministra la lista de colores generada en formato hexadecimal
colores

# Mapea la paleta de los colores generados sin borda y sin espacio entre las barras
barplot(rep(1,length(colores)), col=colores, border=NA, space=0, axes=FALSE)





####################### Multicolor #################################################

# La misma funci?n puede ser empleada para generar una paleta con tres o mas colores
multicol <- colorRampPalette(c("blue","yellow","green","red2"))

# Genera una escala de 35 colores segun el orden de los colores mencionados arriba
colores <- multicol(35)

# Mapea la paleta de los colores generados sin borda y sin espacio entre las barras
barplot(rep(1,length(colores)), col=colores, border=NA, space=0, axes=FALSE)




######################## RColorBrewer ############################################

# Exibe todas las paletas disponibles en el paquete RColorBrewer
library(RColorBrewer)
par(mar=rep(2,4))
display.brewer.all()

# Selecciona una paleta en particular
colores <- brewer.pal(9,"Spectral")
barplot(rep(1,length(colores)), col=colores, border=NA, space=0, axes=FALSE)

# Combina la colorRampPalette con el RColorBrewer
colores <- brewer.pal(9,"Spectral")
col <- colorRampPalette(colores)
colores <- col(50)
barplot(rep(1,length(colores)), col=colores, border=NA, space=0, axes=FALSE)




###################### Progresion de color - Mapa sin clasificacion ###############################

# Generacion de un mapa sin clasificacion utilizando las funciones de color

# Genera una paleta con colores que van de azul claro a azul oscuro.
col <- colorRampPalette(c("paleturquoise1","blue4"))

# Escala de 52 colores que va del azul claro al azul oscuro
colores <- col(length(provs$pibpct08))

# ordena los casos del mayor para el menor
franjas <- sort(provs$pibpct08)

# Genera el mapa con un grado de color para cada provincia
plot(provs, col=colores[findInterval(provs$pibpct08, franjas, all.inside=TRUE)], border = "black")

# Obtiene el minimo y el maximo de la variable
tempor <- summary(provs$pibpct08)
minim <- round(tempor[1],1)
maxim <- round(tempor[6],1)

# Paquete fields - necesario para crear la barra de colores.
library(fields)

# Funcion image.plot(.) - genera la barra de colores en el mapa.
# Parametros:
#    add=TRUE - adiciona la barra al mapa anterior
#    legend.only=TRUE - solo adiciona la leyenda
#    legend.shrink=0.25 - define el tamano de la leyenda (en este caso pequena)
#    legend.width=0.6 - define el grosor de la leyenda.
#    zlim=c(min, max) - define los limites de la leyenda (en el caso de la variable de interes)
#    col=colores - define los colores que seran utilizados
#    horizontal = FALSE - la orientacion sera vertical.
image.plot(add=TRUE, legend.only=TRUE, legend.shrink=0.5, legend.width=0.6, zlim= c(minim,maxim), col = colores, horizontal = FALSE)





#######################################################################################################
########################## Preparacion de los mapas para la publicacion ###############################
#######################################################################################################


############################ Preparando el layout del grafico ###########################

# Empleo del parametro mfrow

# Divide la ventana en 1 linea y dos columnas y reduce los margenes
par(mfrow=c(1,2))
par(mar=rep(0,4))

# Genera dos veces el mapa de las comunidades autonomas, como ilustracion 

# mapa 1
plot(ccaacont)
# mapa 2
plot(ccaacont)

# Abre el archivo con los datos que seran representados en los distintos mapas
gini <- read.csv("gini_peru.csv", header=TRUE, sep=";")

# Abre el archivo de mapas de los departamentos de Peru
pe <- readShapeSpatial("pe.shp")

# Genera una paleta con colores que van de azul claro a azul oscuro.
col_dif <- colorRampPalette(c("blue4","white","orangered2"))

# Ordena los anos a que se desea representar y se obtiene el numero de anos y su cuadrado
years <- sort(unique(gini$year))
n_years <- length(years)
root <- round(sqrt(n_years))

# Establece la escala de colores
colores <- brewer.pal(3,"Greys")
colores[1] <- "white"


# Define el numero ideal de lineas y columnas a ser representado en la ventana
# El cuadrado se utiliza para definir cual es el formato de la ventana - si rectangular
# o cuadrada, en el caso en que root^2 sea igual al numero de anos
if (root^2<n_years) par(mfrow=c(root, root+1))
if (root^2>=n_years) par(mfrow=c(root, root))

# Genera del Gini de los departamentos de Peru para cada ano
for (i in 1:n_years){

# Selecciona solo los valores para el ano de referencia
gini_year <- subset(gini, year==years[i])  


# Franjas- ordena los casos del mayor Gini para el menor
franjas <- c(0,0.5,0.6,1)

# Genera el mapa con un grado de color para cada provincia
plot(pe, col=colores[findInterval(gini_year$gini, franjas, all.inside=TRUE)], border = "black")

# Anade un titulo (con el ano)
if(i!=length(years)) text(-80.64607,-16.02095, years[i])

# Aade la leyenda para el ltimo ao (para evitar repeticiones).
if(i==length(years)){
  legend("bottomleft",legend=leglabs(franjas,"<",">"), fill=colores,border="transparent", bty="n", x.intersp=0.2, cex=0.9)
  text(-70,-7, years[i], bty="n")
  }
}


################ Empleo de la funcion layout(.) #######################################


# Se crea una matriz (m) con 3 lineas y tres columnas: 1,1,2; 1,1,3; y 1,1,4.
# Se establece que esa matriz sirve de base para la creacion del layout
m <- matrix(c(1,1,2,1,1,3,1,1,4),3,3, byrow=TRUE)
layout(m)
layout.show(4)

# Separa los datos para el Gini de 2010 de los departamentos de Peru
ga <- subset(gini, year==2000)
colores <- brewer.pal(3,"Greys")
colores[1]<- "white"
franjas <- c(0,0.5,0.6,1)

# Reduce los margenes, dibuja el mapa y anade el titulo
par(mar=c(0,0,0,0.1))
plot(pe, col=colores[findInterval(ga$gini, franjas, all.inside=TRUE)], border = "black")
text(-70,-7, "Gini 2000", cex=1.5)
legend("bottomleft",legend=leglabs(franjas,"<",">"), fill=colores,border="transparent", bty="n", x.intersp=0.2, cex=2)

# Dibuja los demas graficos: histograma, la densidad de kernel y el boxplot
par(mar=c(2,2,2,0.1))
hist(ga$gini, main="Histograma")
plot(density(ga$gini), main="Kernel density")
boxplot(ga$gini, main = "Boxplot")


########################### Composiciones complejas ##############################################

# Basemaps

# Obteniendo el bounding box
par(mfrow=c(1,1))
bmad <- bbox(ccaacont[ccaacont$NOMBRE_CCA=="Madrid (Comunidad de)",])
plot(ccaacont)
rect(xleft=bmad[1,1], xright=bmad[1,2], ybottom=bmad[2,2], ytop=bmad[2,1], border="red")


# Carga las bibliotecas OpenStreetMap y rgdal necesarias para cargar los mapas y reproyectarlos
library(OpenStreetMap)
library(rgdal)


# Obtiene las coordinadas del bounding box que circunda el mapa de las comunidades autonomas:
boubox <- bbox(ccaacont)

# La funcion openmap(.) abre un mapa de OpenStreetMaps.
# Los parametros son:
#             upperLeft - coordinadas del rincon superior izquierdo del mapa a ser descargado
#             lowerRight - coordinadas del rincon inferior derecho del mapa a ser descargado
#             type - tipo de mapa: osm - para mapa de calles y carreteras y bing para fotos de satelite
map <- openmap(c(boubox[2,2],boubox[1,1]), c(boubox[2,1],boubox[1,2]), type="bing")

# Convierte al mapa de OpenStreetMaps a una misma proyeccion geografica de Latitud/Longitud
map <- openproj(map, projection = "+proj=longlat +datum=WGS84")

# Dibuja los mapas superpuestos
par(mar=rep(0,4))
plot(ccaacont, border="transparent")
plot(map, add=T)
plot(ccaacont, col="orange",add=T)


# Metodo alternativo de construir un base map

# Abre el Shape de todos los paises del mundo y obtiene el bounding box de las comunidades autonomas
paises <- readShapeSpatial("mundo.shp")
bprov <- bbox(ccaacont)

# utilizando xlim e ylim, genera un mapa base que da el contexto del mapa
par(mar=rep(0,4))
plot(paises, xlim=bprov[1,], ylim=bprov[2,], bg="lightblue")

# Una vez establecida la base, basta con pintar los paises de beige y anadir la capa de las comunidades autonomas en naranja.
plot(paises, col="wheat1", add=T)
plot(ccaacont, add=T, col="orange")



################## Inset Map #######################################################

# Creacion de un recuadro (Inset Map) en el mapa de Espana


# Paso 1: Prepara el archivo de provincias y clasificacion de datos/eleccion del color 


# Vuelve a abrir el mapa de las provincias (incluyendo Canarias)
provs <- readShapeSpatial("provincias.shp")

# Fusiona con los datos
datos <- read.csv("prov_educacion.csv", header=TRUE, sep=";")
provs <- spChFIDs(provs, as.character(provs$SP_ID))
row.names(datos) <- datos$ID_2
provs <- SpatialPolygonsDataFrame(provs, datos,match.ID=T)
paises <- readShapeSpatial("mundo.shp")
bprov <- bbox(provs[provs$prov_nombre!="Las Palmas",])


# Paso 2: Generacion del Layout y la creacion del Inset Map

# Genera un layout en el cual las Canarias pueden ser incluidas como un inset map
lay <- layout(matrix(c(1,1,1,1,1,2, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1), 6, 6, byrow = FALSE))
layout.show(lay)

# Clasifica a los datos (natural breaks) en cuatro categorias y encuentra colores
library(RColorBrewer)
colores <- brewer.pal(4, "Oranges")
int <- classIntervals(provs$pibpct08, 4, "jenks")
breaks <- round(int$brks)
colores <- findColours(int, colores)


# Genera el mapa con un grado de color para cada provincia
par(family="times")
par(mar=c(0.3,0.3,0.3,0.3))
plot(paises, xlim=bprov[1,], ylim=bprov[2,], bg="lightblue")
plot(paises, xlim=bprov[1,], ylim=bprov[2,], col="wheat1", add=T, lwd=0.5)
plot(provs, col=colores, border = "black", add=T)

# Genera la leyenda
leyenda <- leglabs(format(breaks, decimal.mark=",",big.mark="."), under="<", over=">", between="a")
legend("bottomright", legend = leyenda, fill = sort(unique(colores), decreasing=T), cex= 1.2, pt.cex = cex, title = "PIB per capita (2008)", bg="beige")


# Anade el inset map utilizando los mismos parametros del mapa anterior

# Genera el encuadre adecuado para representar las Canarias
bcan <- bbox(provs[provs$ccaa_nombre=="Las Palmas",])

# Anade las Canarias como un Inset Map
par(mar=c(0.4,0.4,0,0))
plot(provs, col=colores, border = "black", xlim=bcan[1,], ylim=bcan[2,])
box()
par(family="")






############################ Guardando el archivo final ###########################


# Genera el histograma para el Gini de los departamentos de Peru entre 1999 y 2010
par(mar=rep(4,4))
hist(gini$gini)

#Guarda el histograma de distintas maneras

# Paso 1: Funcion jpeg para crear un archivo de tipo JPEG
# Parametros:
#             filename - nombre del archivo
#             width - largo del imagen en pixels (puede ser en pulgadas, cm o mm)
#             height - alto del imagen en pixels (puede ser en pulgadas, cm o mm)
#             res - resolucion del imagen en puntos por pulgadas (ppp)
jpeg("hist_gini.jpg", width=1024, height=768, res=300)

# Paso 2: Genera el histograma
hist(gini$gini)

# Paso 3: Guarda los resultados de forma definitiva en el archivo
dev.off()


########### Ejemplos alternativos para el mismo procedimiento ####################

# Paso 1: Elegir la funcion para crear el tipo de archivo externo deseado
pdf("hist_gini.pdf", width=1024, height=768)   
win.metafile("hist_gini.wmf", width=1024, height=768, res=300) 
png("hist_gini.png", width=1024, height=768, res=300) 
bmp("hist_gini.bmp", width=1024, height=768, res=300)
tiff("hist_gini.tif", width=1024, height=768, res=300)
postscript("hist_gini.ps", width=1024, height=768, res=300)

# Paso 2: Genera el histograma
hist(gini$gini)

# Paso 3: Guarda los resultados de forma definitiva en el archivo
dev.off()



###############################################################################
############ FINAL DEL ARCHIVO DE EJEMPLOS - CAPITULO 3 #######################
###############################################################################



