#############################################################################################
#   
#   REPRESENTACION ESPACIAL Y MAPAS 
#    
#   por
#
#   Rodrigo Rodrigues-Silveira
#   rodrodr@gmail.com
#   
#   CUARTO CAPITULO - EJEMPLOS
#
#   Este codigo esta destinado a ser utilizado en el paquete estadistico R
#   R version 3.0.1 (Windows). Ademas, para que funcione, todos los archivos denominados
#   "material auxiliar" deben estar presentes en la carpeta:
#   u\\CIS\\Material Auxiliar\\
#   En el caso de que el usuario desee utilizar otra carpeta, debe alterar el 
#   contenido de la variable "cdt" - carpeta de trabajo, mas abajo.
#   
#   Ultima revision: 19 de julio de 2013.
###########################################################################################

# Establece la carpeta de trabajo (espacio donde estan ubicados los archivos auxiliares)
rm(list=ls())
cdt <- c("u/CIS/Material Auxiliar/Shapes/")
setwd(cdt)
windowsFonts(times="Times New Roman")
par(family="times")

#######################################################################################################
################################# La confeccion de Mapas Tematicos ####################################
#######################################################################################################


###############  Mapa Tematico - de Coropletas #######################################


# Vuelve a abrir el mapa de las provincias (incluyendo Canarias)
library(maptools)
provs <- readShapeSpatial("provincias.shp")

# Fusiona con los datos
datos <- read.csv("prov_educacion.csv", header=TRUE, sep=";")
provs <- spChFIDs(provs, as.character(provs$SP_ID))
row.names(datos) <- datos$ID_2
provs <- SpatialPolygonsDataFrame(provs, datos,match.ID=T)


# Genera un layout en el cual las Canarias pueden ser incluidas como un inset map
lay <- layout(matrix(c(1,1,1,1,1,2, 1,1,1,1,1,2, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1), 6, 6, byrow = FALSE))
layout.show(lay)

# Clasifica a los datos (natural breaks) en cuatro categorias y encuentra colores
library(RColorBrewer)
library(classInt)
colores <- brewer.pal(4, "Oranges")
int <- classIntervals(provs$pibpct08, 4, "jenks")
breaks <- round(int$brks)
colores <- findColours(int, colores)


# Genera el mapa con un grado de color para cada provincia y encuadra el mapa para evitar que Espana continental se quede demasiado pequena 
bcan <- bbox(provs[provs$ccaa_nombre!="Las Palmas",])
plot(provs, col=colores, border = "black", xlim=bcan[1,], ylim=bcan[2,])

# Genera la leyenda
leyenda <- leglabs(format(breaks, decimal.mark=",",big.mark="."), under="<", over=">", between="a")
legend("bottomright", legend = leyenda, fill = sort(unique(colores), decreasing=T), cex= 1.2, pt.cex = cex, title = "PIB per capita (2008)", bg="beige")

# Genera el encuadre adecuado para representar las Canarias
bcan <- bbox(provs[provs$ccaa_nombre=="Las Palmas",])

# Anade las Canarias como un Inset Map
par(mar=c(0.4,0.4,0.1,0.1))
plot(provs, col=colores, border = "black", xlim=bcan[1,], ylim=bcan[2,])
box()



###############  Mapa Tematico - Densidad de puntos #######################################

# Restablece los parametros graficos para una ventana de solo un mapa
par(mfrow=c(1,1))


# Abre el archivo de mapas de las escuelas de Sao Paulo
esc_est <- readShapeSpatial("esc_estadual.shp")

# Abre el archivo de mapas de los barrios de Sao Paulo
sp <- readShapeSpatial("distritos_SP.shp")


# Tipo 1a: Puntos Sencillos

# Genera el mapa de los barrios de Sao Paulo
plot(sp)

# Anade en Azul las escuelas (add=TRUE)
plot(esc_est, col = "blue", pch=19, cex=0.5, pt.cex =1, add=TRUE)

# Genera el mapa de las fronteras de los barrios de Sao Paulo
# En este caso las fronteras se agregan a posteriori porque la densidad de los
# puntos es demasiado alta, lo que ocultaria los limites entre barrios si estos
# fueran mapeados primero.
plot(sp, add=TRUE)

# Anade una leyenda
legend("bottomright", pch=19, col="blue", legend="Escuelas", bty="n")



# Cores distintas para distintos tipos

# Se define un color para cada elemento unico de una variable, en este caso las directorias de ensenanza
library(RColorBrewer)
colores <- brewer.pal(8, "Accent")
col <- colorRampPalette(colores)
dir <- sort(unique(esc_est$COD_DIR))
colores <- col(length(dir))

# Se atribuye a cada directoria un color especifico
esc_est$col <- "transparent"
for (i in 1:length(dir)) esc_est$col[esc_est$COD_DIR==dir[i]] <- colores[i]

# Se dibuja el mapa y anade una leyenda
plot(sp)
plot(esc_est, pch=19, cex=0.8, col=esc_est$col,add=T)
plot(sp, add=T)
legend("bottomright", legend=dir, pch=19, col=colores, bty="n", y.intersp=0.7)

# Gradaciones de color

# Se genera aleatoriamente una variable del numero de alumnos (esta informacion no consta de la base de datos original)
set.seed(12345)
esc_est$alumnos <- rnorm(length(esc_est), mean=500, 200)

# Como en un mapa coropletico, se elige la paleta de colores y se clasifican los datos
colores <- brewer.pal(4, "Oranges")
int <- classIntervals(esc_est$alumnos, 4, "jenks")
breaks <- round(int$brks)
colores <- findColours(int, colores)

# Se dibuja el mapa con su respectiva leyenda
plot(sp)
plot(esc_est, pch=19, cex=0.8, col=colores,add=T)
plot(sp, add=T)
leyenda <- leglabs(breaks, under="<", over=">", between="a")
legend("bottomright", legend = leyenda, col = sort(unique(colores), decreasing=T), pch=19, pt.cex = 1, cex=1, title = "Alumnos", bty="n")



# tipo 2a: Simbolos distintos para distintos tipos

# Grafico con los principales simbolos preprogramados del R
plot(1:26,rep(1,26), pch=c(0:25), cex=2, col="black", bg="red")

# Selecciona aleatoriamente 150 escuelas para facilitar el reconocimiento de los simbolos en en mapa
id <- 1:length(esc_est)
samp <- sample(id, 100,replace=F)
escsamp <- esc_est[samp,]
coord <- escsamp@coords


# Agrega a los distritos en zonas mas generales (Centro, Este, Norte y Sur)
escsamp$simb <- ""
escsamp$simb[escsamp$COD_DIR %in% c("001","002","003")] <- "Centro"
escsamp$simb[escsamp$COD_DIR %in% c("004","005","006","007","008")] <- "Este"
escsamp$simb[escsamp$COD_DIR %in% c("011","012","013")] <- "Sur"
escsamp$simb[escsamp$COD_DIR %in% c("009","019")] <- "Norte"
escsamp$simb[escsamp$simb==""] <- "Norte"

# Establece un simbolo preprogramado del R para cada categoria
escsamp$pch <- 15
escsamp$pch[escsamp$simb=="Este"] <- 16
escsamp$pch[escsamp$simb=="Sur"] <- 17
escsamp$pch[escsamp$simb=="Norte"] <- 18

# Se genera el mapa con su respectiva leyenda
plot(sp)
plot(escsamp, pch=escsamp$pch, add=T)
plot(sp, add=T)
reg <- sort(unique(escsamp$simb))
legend("bottomright", legend = reg, pch=c(15,16,18,17), pt.cex = 1, cex=1, title = "Regiones", bty="n")


# Tipo 2b: fontes TTF - velocidad y flexibilidad

# Se elige una familia de fuentes TTF que servira de base para los simbolos
windowsFonts(FAM1 = windowsFont("Webdings"))

# Se atribuye a cada categoria un simbolo (que corresponde a una letra o numero en Lucida Console que es la fuente utilizada por el RStudio)
escsamp$let <- ""
escsamp$let[escsamp$simb=="Centro"] <- "d"
escsamp$let[escsamp$simb=="Este"] <- "f"
escsamp$let[escsamp$simb=="Sur"] <- "b"
escsamp$let[escsamp$simb=="Norte"] <- "l"

# Se genera el mapa base, se anade el texto utilizando la fuente apropiada.
plot(sp)
text(coord[,1], coord[,2], escsamp$let, family = "FAM1", cex=0.8)

# La leyenda se anade en dos pasos: primero los simbolos y luego su descripcion
par(family="FAM1")
legend(x=342712.3, y=7361320, legend=c("d","f","l","b"), bty="n", adj=1)
par(family="times")
legend(x=342712.3, y=7361320, legend=c("Centro","Este","Norte","Sur"), bty="n")


# Tipo 2u Imagenes png o svg

# Carga los paquetes exigidos para llevar a cabo la tarea
library(png)
library(TeachingDemos)

# Abre los archivos de imagenes
lapiz <- readPNG("glyphicons_030_pencil.png")
clip <- readPNG("glyphicons_062_paperclip.png")
regla <- readPNG("glyphicons_068_ruller.png")
div <- readPNG("glyphicons_249_divide.png")

# Obtiene las coordinadas de todas las escuelas
coord <- esc_est@coords
coord <- coord[samp,]

# Dibuja el mapa base
par(mar=rep(0,4))
plot(sp)

# Anade primero la leyenda (caso contrario no permitira anadir texto al grafico luego)
text(x=rep(346383.4,4), y=c(7366598, 7361598, 7356598, 7351598), c("Centro","Este","Norte","Sur"), adj=0)

my.symbols(344383.4, 7366598, ms.image, MoreArgs=list(img=lapiz), inches=0.2, symb.plots=TRUE, add=T)
my.symbols(344383.4, 7361598, ms.image, MoreArgs=list(img=clip), inches=0.2, symb.plots=TRUE, add=T)
my.symbols(344383.4, 7356598, ms.image, MoreArgs=list(img=regla), inches=0.2, symb.plots=TRUE, add=T)
my.symbols(344383.4, 7351598, ms.image, MoreArgs=list(img=div), inches=0.2, symb.plots=TRUE, add=T)

# Anade los simbolos con las coordinadas de cada escuela
my.symbols(coord[escsamp$simb=="Centro",1], coord[escsamp$simb=="Centro",2], ms.image, MoreArgs=list(img=lapiz), inches=0.15, symb.plots=TRUE, add=T)
my.symbols(coord[escsamp$simb=="Este",1], coord[escsamp$simb=="Este",2], ms.image, MoreArgs=list(img=clip), inches=0.15, symb.plots=TRUE, add=T)
my.symbols(coord[escsamp$simb=="Norte",1], coord[escsamp$simb=="Norte",2], ms.image, MoreArgs=list(img=regla), inches=0.15, symb.plots=TRUE, add=T)
my.symbols(coord[escsamp$simb=="Sur",1], coord[escsamp$simb=="Sur",2], ms.image, MoreArgs=list(img=div), inches=0.15, symb.plots=TRUE, add=T)




#################### Mapa Tematico - Simbolos proporcionales #############################################

# **a. Parte comun a los dos tipos de mapa**

# Abre el archivo Shape de las comunidades autonomas y convierte el objeto en puntos (centroides)
ccaa <- readShapeSpatial("ccaa.shp")
ccaapt <- SpatialPointsDataFrame(ccaa, data.frame(ccaa))

# Define el tamano maximo del tamano del punto a ser representado
nmax <- 7



# Calculo del tamano de cada punto (con base en el tamano maximo de punto previamente definido para cex)
# Dos tipos:  
# - Matematico - cada cual es representado por su valor relativo de la variable en cuestion
# - Perceptual - Reduce el peso visual de los valores mas grandes
ccaapt$size <- (ccaapt$POBLACION/max(ccaapt$POBLACION, na.rm=T))^0.5*nmax       # Matematico
ccaapt$size <- (ccaapt$POBLACION/max(ccaapt$POBLACION, na.rm=T))^0.57*nmax      # Perceptual


#Calculo de los tamanos, de la legenda y del ordem de diseno de los elementos
legs <- sort(round(quantile(ccaapt$POBLACION,seq(0,1,1/3), na.rm=T),0),decreasing=T)
ri <- (legs/max(legs, na.rm=T))^0.5*nmax      # Matematico
ri <- (legs/max(legs, na.rm=T))^0.57*nmax # Perceptual


#Establece el orden de diseno de los mayores a los menores para evitar que la superposicion oculte puntos.
ccaapt$plotOrder<- order(sort(ccaapt$size, decreasing=T))



#**b. Simbolos proporcionales - sencillo (fig.4.3a)**
  
  
# Utilizamos el layout para incluir a Canarias
lay <- layout(matrix(c(1,1,1,1,1,2, 1,1,1,1,1,2, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1), 6, 6, byrow = FALSE))

# Dibuja el mapa de las comunidades autonomas teniendo Espana continental como base
par(mar=rep(0,4))
plot(ccaa, xlim=bbox(ccaa[ccaa$NOMBRE_CCA!="Canarias",])[1,] , ylim=bbox(ccaa[ccaa$NOMBRE_CCA!="Canarias",])[2,], col="wheat1")
plot(ccaapt, cex=ccaapt$size, col="black", bg="red", pch=21, add=T)

# Formata los valores para que sean mas legibles
legs <- format(legs, big.mark=".")
legend("bottomright", legend=legs[1:length(legs)-1], col="black", pt.bg="red",pch=21,pt.cex=ri[1:length(ri)-1], cex=2, bty="n", bg="transparent", y.intersp=1, x.intersp=1)

# Repite el procedimiento, pero para el encuadre de Canarias
bcan <- bbox(ccaa[ccaa$NOMBRE_CCA=="Canarias",])
plot(ccaa, xlim=bcan[1,] , ylim=bcan[2,], col="wheat1")
plot(ccaapt, cex=ccaapt$size, col="black", bg="red", pch=21, add=T)

# **c. Simbolos con gradaciones de color - Figura 4.3b**
  
# Se utilizan los mismos pasos anteriores con las siguientes diferencias:
# A) Antes de dibujar el mapa, se define una variable de color dividiendo a los casos
# B) Se anada una leyenda para identificar las clases


# Clasifica a los datos (natural breaks) en cuatro categorias y encuentra colores

colores <- brewer.pal(4, "PuBu")
colpt <- min(colores)
int <- classIntervals(ccaapt$POB_PER, 4, "jenks")
breaks <- round(int$brks)
ccaapt$col <- as.vector(findColours(int, colores))


# Genera el mapa


# Utilizamos el layout para incluir a Canarias
lay <- layout(matrix(c(1,1,1,1,1,2, 1,1,1,1,1,2, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1, 1,1,1,1,1,1), 6, 6, byrow = FALSE))

# Dibuja el mapa de las comunidades autonomas teniendo Espana continental como base
par(mar=rep(0,4))
plot(ccaa, xlim=bbox(ccaa[ccaa$NOMBRE_CCA!="Canarias",])[1,] , ylim=bbox(ccaa[ccaa$NOMBRE_CCA!="Canarias",])[2,], col="wheat1")
plot(ccaapt, cex=ccaapt$size, bg=ccaapt$col, pch=21, add=T)

# Anade las leyendas

# Leyenda del mapa de simbolos
legs <- format(legs, big.mark=".")
legend("bottomright", legend=legs[1:length(legs)-1], col="black", pt.bg=colpt,pch=21,pt.cex=ri[1:length(ri)-1], cex=2, bty="n", bg="transparent", y.intersp=1, x.intersp=1, title="Poblacion")

# Leyenda del intervalo de valores
leyenda <- leglabs(format(breaks, decimal.mark=",",big.mark="."), under="<", over=">", between="a")
legend("bottom", legend = leyenda, fill = sort(unique(colores), decreasing=T), cex= 1.8, title = "Pob. (%)", y.intersp=0.7, x.intersp=0.8, bty="n")

# Anade a Canarias en el mapa
bcan <- bbox(ccaa[ccaa$NOMBRE_CCA=="Canarias",])
plot(ccaa, xlim=bcan[1,] , ylim=bcan[2,], col="wheat1")
plot(ccaapt, cex=ccaapt$size, bg=ccaapt$col, pch=21, add=T)

# Restablece los parametros graficos originales.
par(mfrow=c(1,1))






#################### Mapa Tematico - Mapa ISOPLETICO ##############################################

# Paso 1 - genera la densidad de KERNEL y la rejilla 

# Abre los archivos de mapa basicos

# Abre el archivo de mapas (area) de los barrios de la ciudad de Sao Paulo en Brasil
sp <- readShapeSpatial("distritos_SP.shp")

# Abre el archivo de mapas de las escuelas de Sao Paulo (puntos)
esc_est <- readShapeSpatial("esc_estadual.shp")

# La funcion spastat.options(.) deshabilita la opcion de averiguar la superposicion de
# poligonos a la hora de crear la rejilla. En el momento posterior, una vez creada
# la rejilla, se reactiva la opcion. 
library(spatstat)
spatstat.options(checkpolygons=FALSE)

# La funcion as.owin.SpatialPolygons(.), genera la rejilla a ser utilizada en la funcion
# Kernel(.) segun el mapa de barrios de la ciudad de Sao Paulo.
sp_owin <- as.owin.SpatialPolygons(sp)

# reactivacion de la opcion de averiguacion de superposicion de poligonos.
spatstat.options(checkpolygons=TRUE)

# Obtiene las coordenadas de las escuelas de Sao Paulo
cord_esc <- esc_est@coords

# Genera el objeto de puntos que servira para representar el mapa ISOPLETICO
# la funcion as.ppp(.) necesita de dos parametros - las coordinadas y la ventana (W - window)
# que es como una forma que establece los limites para los puntos.
pt_esc <- as.ppp(cord_esc, W=sp_owin)

# Calcula la funcion de densidad de Kernel para el archivo de puntos
# density(.) - objeto de puntos y "n=" numero de estimaciones para la gradacion
#             en el mapa.
kr_esc <- density(pt_esc, n=1000)

# Paso 2 - Genera el MAPA ISOPLETICO 

# Mapea la funcion de densidad de Kernel para las Escuelas
# topo.colors(12) - funcion de colores pre-programada de R que representa una
#                   escala topografica de colores. Otras funciones son:
#                   rainbow(n), heat.colors(n), terrain.colors(n), cm.colors(n)
# main= - titulo del grafico. 
plot(kr_esc, col = topo.colors(8), main="Escuelas (kernel)")

# Anade al mapa anterior las fronteras de los barrios de Sao Paulo
plot(sp, add=T)

# Mapa Isopletico - lineas de contorno

# Para obtener los contornos de cada area de color (y no los barrios):

# Abre el archivo de mapas (area) de los barrios de la ciudad de Sao Paulo en Brasil
sp_tot <- readShapeSpatial("SP_front_pol.shp")

# Genera el mapa de contornos equivalente a la figura en colores del procedimiento anterior
# kr_esc - objeto con la densidad de kernel para los puntos
# nlevels - numero de niveles de contorno (de preferencia el mismo para los colores)
# labels - aqui se ha elegido de 0 - punto central a 7 - punto mas distante
contour(kr_esc, nlevels=8, main="Escuelas (Kernel)", labels=c(0,7,6,5,4,3,2,1), axes=FALSE)

# Dibuja las fronteras de la ciudad de Sao Paulo
plot(sp_tot, add=TRUE)



################# Mapa Isopletico a partir de caracteristicas de la poblacion ####################

# Calcula el porcentaje de alfabetizacion en los barrios de Sao Paulo
sp$alfab_per <- sp$ALFABETIZA / sp$POPULACAO * 100

# Funcion dotsInPolys(.) - genera un mapa de puntos para la variable de interes
# Parametros:
#             sp - objeto de tipo SpatialPolygon (mapa de area) que servira de base
#             sp$alfab_per - variable de interes contenida en el mapa de area
alfa <- dotsInPolys(sp, sp$alfab_per)


# Se repite el procedimiento llevado a cabo en el mapa Isopletico anterior
library(spatstat)
spatstat.options(checkpolygons=FALSE)
sp_owin <- as.owin.SpatialPolygons(sp)
spatstat.options(checkpolygons=TRUE)

# Obtiene las coordenadas de las escuelas de Sao Paulo
cord_alfa <- alfa@coords

# Genera el objeto de puntos que servira para representar el mapa ISOPLETICO
pt_alfa <- as.ppp(cord_alfa, W=sp_owin)

# Calcula la funcion de densidad de Kernel para el archivo de puntos
knl_alfa <- density(pt_alfa, n=1000)

# Genera el mapa ISOPLETICO - Anillos de color 
plot(knl_alfa, col = topo.colors(8), main="Alfabetizados (%)")
plot(sp, add=TRUE)

# Genera el mapa ISOPLETICO - Lineas de contorno 
contour(knl_alfa, nlevels=8, main="Alfabetizados (%)", labels=c(0,7,6,5,4,3,2,1), axes=FALSE)
plot(sp_tot, add=TRUE)


############ Mapa Tematico - CARTOGRAMA - ANAMORFICO ############


# Este tipo de mapa tambien ha sido realizado con mas de un procedimiento.
# La ausencia (todavia) de un algoritmo funcional para generar cartogramas en el
# R, nos ha obligado a hacer uso de un programa externo para realizar dicha tarea.
# El programa utilizado ha sido el ScapeToad, que puede ser encontrado, de
# forma gratuita en la direccion: http://scapetoad.choros.ch/index.php

# Para realizar el mapa anamorfico (o cartograma) utilizamos el archivo
# ccaa.shp y la variable POBLACION. Una vez creado el cartograma, se ha guardado
# el resultado en el archivo denominado "cartograma.shp". 

# El ultimo paso ha sido abrir el archivo cartograma.shp en el R y 
# pedir para que el programa dibujara el mapa.

# Abre el archivo shape del cartograma creado por el programa ScapeToad
carto <- readShapeSpatial("cartograma.shp")

# Genera el mapa del cartograma
plot(carto, col="grey90", border = "black")




######################### Mapa Tematico - MAPA de FLUJOS ###########################################

# Paso 1: abre los archivos de mapas y los datos

# Abre el archivo de mapas de las Comunidades Autonomas
library(maptools)
ccaa <- readShapeSpatial("ccaa.shp")

# Abre el archivo de mapas de los centroides de las CCAA
ccaa_cid <- readShapeSpatial("centroids_ccaa.shp")

# Abre el archivo con los datos de las migraciones internas en 2010 en Espana
# Fuente: INE - Estadisticas de variaciones residenciales interiores 2010.
migra_cyl <- read.csv("migra_cyl.csv", header=TRUE, sep=";")



# Paso 2 - Vincula las coordinadas geograficas de origen (Castilla y Leon) y
#         destino (demas comunidades) con los datos de migracion

# Obtiene las coordinadas geograficas del punto de origen, en este caso el 
# centroide de Castilla y Leon.
origen <- c(ccaa_cid$X[ccaa_cid$CC_COD==7], ccaa_cid$Y[ccaa_cid$CC_COD==7])

# Calcula la proporcion que cada CCAA representa del total de emigrantes
# este indicador sera util para definir el grosor de la linea de cada CCAA.
migra_cyl$wdt <- migra_cyl$migra /sum(migra_cyl$migra)

# Genera las coordinadas de origen y destino para cada CA que ha recibido 
# migrantes de Castilla y Leon  
for (i in 1:nrow(migra_cyl)){
  # Define el punto de origen para todos los casos
  migra_cyl$orX[i] <- origen[1]
  migra_cyl$orY[i] <- origen[2]
  
  # Define el punto de destino para cada caso
  migra_cyl$desX[i] <- ccaa_cid$X[ccaa_cid$CC_COD==migra_cyl$cc_cod[i]]
  migra_cyl$desY[i] <- ccaa_cid$Y[ccaa_cid$CC_COD==migra_cyl$cc_cod[i]]
}


# Paso 3 - Genera el mapa con TODAS las CCAA que han recibido emigrantes de 
#          Castilla y Leon

# Mapea las fronteras de las comunidades autonomas
plot(ccaa)

# SETAS - la funcion arrows(.) permite dibujar setas seg?n un origen y destino especificados 
# en un mapa. B!Ojo! Para que funcione, el mapa debe haber sido ya dibujado. 
# Parametros de la funcion arrows(.):
#       X del origen
#       Y del origen
#       X del destino
#       Y del destino
#       demas parametros relacionados con el tamano, color y forma de la punta de la seta y
#       otros atributos. Para mas informacion - help(arrows)
arrows(migra_cyl$orX,migra_cyl$orY, migra_cyl$desX, migra_cyl$desY, length=0.1, lwd=1+(10*migra_cyl$wdt),arr.width=0.1, arr.length=0.1)

# Paso 4 - Genera el mapa con solamente las CCAA que han recibido mas de 50 emigrantes de 
#          Castilla y Leon

# Selecciona las CCAA que han recibido mas de 50 emigrantes
mas_50 <- subset(migra_cyl, migra >=50)

# dibuja las setas (del mismo modo en que el ejemplo anterior)
arrows(mas_50$orX,mas_50$orY, mas_50$desX, mas_50$desY, length=0.1, lwd=1+(10*mas_50$wdt))

# SETA CURVA 

# El R permite tambien hacer uso de setas curvas, lo que ayuda a evitar la 
# superposicion y hacer mas clara la representacion de los datos.

# Para eso se empleara la funcion curvedarrow(.) del paquete "diagram"
library(diagram)

# Vuelve a dibujar el mapa base.
plot(ccaa)

# Para cada una de las CCAA con mas de 50 emigrantes de CyL
for (i in 1:nrow(mas_50)){
  
  # Si representa el mayor flujo (valor maximo) - dibuja una seta recta y azul
  if (mas_50$migra[i] == max(mas_50$migra)){
    arrows(mas_50$orX[i],mas_50$orY[i], mas_50$desX[i], mas_50$desY[i], length=0.1,      lwd=1+(10*mas_50$wdt[i]), col="blue")
  }
  # Caso contrario: dibuja las setas curvas con el tamano segun su proporcion en el total de emigrantes
  else {
    curvedarrow(c(mas_50$orX[i],mas_50$orY[i]), c(mas_50$desX[i], mas_50$desY[i]), curve=0.1, lwd=1+(10*mas_50$wdt[i]), arr.pos=1, arr.width=0.1, arr.length=0.1)
  }
}

