#############################################################################################
#   
#   REPRESENTACION ESPACIAL Y MAPAS 
#    
#   por
#
#   Rodrigo Rodrigues-Silveira
#   rodrodr@gmail.com
#   
#   QUINTO CAPITULO - EJEMPLOS
#
#   Este codigo esta destinado a ser utilizado en el paquete estadistico R
#   R version 3.0.1 (Windows). Ademas, para que funcione, todos los archivos denominados
#   "material auxiliar" deben estar presentes en la carpeta:
#   C:\\CIS\\Material Auxiliar\\
#   En el caso de que el usuario desee utilizar otra carpeta, debe alterar el 
#   contenido de la variable "cdt" - carpeta de trabajo, mas abajo.
#   
#   Ultima revision: 19 de julio de 2013.
###########################################################################################


# Prepara el ambiente para los ejemplos
rm(list=ls())
cdt <- c("C:/CIS/Material Auxiliar/Shapes/")
setwd(cdt)


# Reduce los margines de la figura
par(mar=c(0,0,0,0.1))



############################### Subgrupo de casos ####################################################

# Carga el paquete maptools y las funciones cartograficas auxiliares
library(maptools)
source("carto_functions.R")

# Abre el archivo de mapa de los sectores censales del estado de Bahia en Brasil
ba <- readShapeSpatial("bahia.shp")

# Selecciona solamente los sectores censales que pertenecen a la ciudad de Salvador (cod. 2927408)
salva <- ba[ba$CD_GEOCODM==2927408, ]

# Limpia el archivo para que no esta el mar
salva <- salva[! salva$CD_GEOCODS %in% c(29274080501, 29274080510),]

# Genera el mapa de: (a) Bahia y (b) Salvador (sectores censales)
plot(ba)
scalebar(c(-45.42748,-17.08611), length=250, unit=1)
plot(salva)
scalebar(c(-38.40745,-12.99407), length=5, unit=1)


############################ Agregacion de Areas por medio de atributos ##############################

# Agrega los sectores por subdistrito
# Parametros
#  	salva el objeto espacial de origen que se desea agregar
#		salva$CD_GEOCODS es la variable que identifica los distritos que seran fusionados
salva_dist <- unionSpatialPolygons(salva, salva$CD_GEOCODS)

# Genera el mapa de los subdistritos de Salvador
plot(salva_dist)

# Obtiene los nombres de cada poligono (que corresponden al codigo del distrito)
row.names(salva_dist)

########## Anadiendo informacion y guardando en un nuevo archivo Shape #############################

# Genera un objeto data.frame con el codigo y el nombre del municipio y de los distritos
id <- data.frame(na.omit(cbind(rep(2927408, 21), rep("Salvador", 21),as.vector(unique(salva$CD_GEOCODS)), as.vector(unique(salva$NM_SUBDIST)))))

# Anade nuevos nombres a las variables del data.frame "id"
names(id) <- c("cod_mun", "nom_mun", "cod_dist","nom_dist")

# Ordena los casos segun el orden correcto de las lineas del objeto espacial obtenido por la funcion 
# row.names(.)
ord <- match(id$cod_dist, row.names(salva_dist))
id <- id[ord,]

# Fusiona los datos con el archivo de los distritos
salva_dist <- SpatialPolygonsDataFrame(salva_dist, id, match.ID=FALSE)

# Guarda los resultados en un nuevo archivo Shape
writeSpatialShape(salva_dist, "salva_dist.shp")
  
# Obtiene las coordinadas de los centroides para crear las leyendas
co_lab <- coordinates(salva_dist)
  


# Anade las primeras letras del nombre de cada distrito al mapa
pointLabel(co_lab[,1], co_lab[,2], labels=substr(salva_dist$nom_dist,1,3), cex=0.8)






########################### Geocodificacion de direcciones ############################################

# Carga la biblioteca XML - requerida para obtener las coordinadas geograficas
library(XML)

# Define la direccion que se desea geocodificar
direccion <- "Palacio de Ondina, Ondina,Salvador"

# Establece la raiz de la direccion Web (URL) de la aplicacion de geocodificacion de Google Maps
raiz <- "http://maps.googleapis.com/maps/api/geocode/xml"

# Genera la direccion web a partir de la direccion informada y busca las informaciones en Google Maps
# address= para la direccion a ser buscada
# &sensor= false  define que no se utiliza un aparato con sensor
# &language=es  define el espanol como lengua base de la busqueda
web <- paste(raiz, "?address=", direccion, "&sensor=false&language=es", sep = "")

# La funcion URLencode(.) convierte la direccion URL enviada en el codigo apropiado para la internet
web <- URLencode(web)

# La funcion xmlTreeParse(.) obtiene los datos de tipo xml para que puedan ser procesados
base_res <- xmlTreeParse(web, useInternal=TRUE)

# Extrae la longitud y latitud de la direccion deseada
long <- sapply(getNodeSet(base_res, "/GeocodeResponse/result/geometry/location/lng"), function(el) xmlValue(el))
lati <- sapply(getNodeSet(base_res, "/GeocodeResponse/result/geometry/location/lat"),function(el) xmlValue(el))

# Retorna los valores de la longitud y latitud obtenidos
print(long)
print(lati)


###################### Dibujando la ubicacion en un mapa estatico de Google Maps ######################

# Abre el paquete RgoogleMaps, necesario para descargar los mapas estaticos de Google Maps
library(RgoogleMaps)

# Convierte la latitud y longitud a numerico y corrige pequenas distorsiones con relacion al mapa estatico de Google Maps y las coordinadas suministradas por la geocodificacion
lati <- as.real(lati[1]) + 0.001
long <- as.real(long[1]) + 0.003

# Obtiene el mapa base por la function GetMap.bbox(.)
# Parametros:
#  	long  longitud
#		lati  latitud
#		destfile archivo temporal de destino en que el archivo serÃ¡ descargado
#		maptype  tipo de mapa del Google "roadmap", "sattelite", "mobile", "terrain", 
#			   "hybrid", "mapaker-roadmap", "mapmaker-hybrid"
#		zoom es el grado de acercamiento deseado para el mapa, cuanto mas alto el valor mas 
#			cercano del punto exacto.
mapa_base <- GetMap.bbox(long, lati, destfile = "teste.png", maptype="roadmap",zoom=14)

# Dibuja el mapa en el R - sin los ejes
PlotOnStaticMap(mapa_base, axes = FALSE)

# Dibuja el punto en la ubicacion deseada
points(long, lati, pch=19, col="red", cex=2)



########################### Geocodificacion reversa ############################################

# Carga la biblioteca XML - requerida para obtener las coordinadas geograficas
library(XML)

# latitud y longitud aleatorias de las cuales se desean obtener informacion
lati <- -12.98327
long <- -38.51505  

# Establece la raiz de la direccion Web (URL) de Google Maps
raiz <- "http://maps.googleapis.com/maps/api/geocode/xml"

# Genera la direccion web a partir de cada par de coordinadas y busca las informaciones en Google Maps
# latlng= latitud , longitud
web <- paste(raiz, "?latlng=", lati, ",", long, "&sensor=false&language=es", sep = "")
web <- URLencode(web)
base_res <- xmlTreeParse(web, useInternal=TRUE)

# Obtiene una lista con las informaciones de direccion
res <- sapply(getNodeSet(base_res, "/GeocodeResponse/result/address_component/long_name"), function(el) xmlValue(el))

# Genera una lista no repetida con las informaciones completas de la direccion perteneciente a esas coordinadas geograficas
unique(res)



################# Generando un mapa de puntos a partir de latitudes y longitudes ####################

# Carga el paquete sp necesario para la conversion de las latitudes / longitudes en coordinadas
library(sp)

# Carga los datos de los hospitales, escuelas y comisarias de poliiia de Salvador
hosp <- read.csv("salvador_hospitales.csv", header=TRUE, sep=";")
esc <- read.csv("salvador_escuelas.csv", header=TRUE, sep=";")
comi <- read.csv("salvador_comisarias.csv", header=TRUE, sep=";")

# Define que las columnas lng y lat de cada base de datos corresponden a la longitud y latitud de los puntos
coordinates(hosp) <- ~lng+lat
coordinates(esc) <- ~lng+lat
coordinates(comi) <- ~lng+lat

# reestablece los margenes
par(mar=c(0,0,0,0.1))

# Genera el mapa de los distritos de Salvador
plot(salva_dist)

# Anade al mapa la ubicacion de los hospitales de Salvador (en azul y con un triangulo)
plot(esc, pch=17, col="darkgreen", cex=1,,add=TRUE)

# Anade al mapa la ubicacion de los hospitales de Salvador (en rojo y con un circulo)
plot(hosp, pch=19, col="red", cex=1.5, add=TRUE)

# Anade al mapa la ubicacion de los hospitales de Salvador (en verde y con un cuadrado)
plot(comi, pch=15, col="blue", cex=1.5, add=TRUE)

# Anade una leyenda al mapa que identifica cada tipo de punto
legend("bottomright", c("Escuelas","Hospitales","Comisarias"), border="transparent", pch=c(17,19,15), col=c("darkgreen","red","blue"), bty="n", cex=1.2)


# Guarda los nuevos mapas de puntos en el formato Shape
writeSpatialShape(hosp, "sv_hosp_pt.shp")
writeSpatialShape(esc, "sv_esc_pt.shp")
writeSpatialShape(comi, "sv_comi_pt.shp")



################# Extrayendo atributos por medio de la superposicion ####################

# Carga el paquete sp 
library(sp)

# Abre los archivos de mapas que se desea comparar
esc <- readShapeSpatial("sv_esc_pt.shp")
salva_dist <- readShapeSpatial("salva_dist.shp")

# Retorna una lista de los distritos a que pertenecen cada una de las escuelas
data <- over(esc, salva_dist)

# Unifica los datos de las escuelas con los de los distritos
esc_dist <- cbind(esc, data)

# Genera una constante de valor 1 para facilitar el recuento de las escuelas
esc_dist$count <- 1

# Obtiene la suma de algunas variables de capacidad de las escuelas en cada distrito
cap <- aggregate(esc_dist[c(17:22,35)], by=list(esc_dist$cod_dist), FUN=sum)

# Genera un data.frame con todos los codigos de los distritos
salva_sum <- merge(salva_dist, cap, by.x="cod_dist", by.y="Group.1", all.x=TRUE)
row.names(salva_sum) <- salva_sum$cod_dist

# Anade las informaciones al objeto espacial salva_dist
library(sp)
salva_dist <- spChFIDs(salva_dist, as.character(salva_dist$cod_dist))
salva_dist <- SpatialPolygonsDataFrame(salva_dist, salva_sum, match.ID=TRUE)

# Exhibe las nuevas variables del objeto espacial salva_dist
View(salva_dist)




############################# Operaciones basicas ################################################


############################# Calculo de area y perimetro ########################################

# Carga los paquetes PBSMapping y rgdal, necesarios para la realizacion de las operaciones geograficas
library(PBSmapping)
library(rgdal)

# Cambia la proyeccion geografica para una UTM que permite convertir la unidad de mensuracion del mapa de grados decimales a kilometros
sv_dist_km <- salva_dist
proj4string(sv_dist_km) <- CRS("+proj=utm +zone=24 +datum=WGS84 +units=km")

# Convierte los limites de los distritos de Salvador a un objeto de tipo PolySet 
sv_dist_ps <- SpatialPolygons2PolySet(sv_dist_km)

# Calcula el area de cada uno de los distritos
salva_dist$area <- calcArea(sv_dist_ps, rollup=1)$area

# Calcula el perimetro de cada uno de los distritos
salva_dist$perimetro <- calcLength(sv_dist_ps, rollup=1)$length

# Inspecciona los resultados
View(salva_dist)


############################## Calculo de distancias ###########################################


#### Distancia entre dos puntos

# Carga el paquete sp, necesario para el calculo de las distancias
library(sp)

# Dibuja los limites de los distritos de Salvador
plot(salva_dist)

# Obtiene dos puntos aleatorios
locator()
pts <- rbind(c(-12.99916, -38.51870), c(-12.92475, -38.43273))

# Calcula la distancia entre los dos puntos
# La el argunto longlat=TRUE, establece que la unidad de retorno seran los kilometros. Si longlat=FALSE
# el resultado seraa la distancia euclidiana 
spDists(pts, longlat=TRUE)

# Abre el archivo de hospitales
hosp <- readShapeSpatial("sv_hosp_pt.shp")

# Genera una matriz con todas las distancias entre los hospitales 
hospdst <- spDists(hosp, longlat=TRUE)

# Exhibe la matriz de distancias entre los hospitales.
View(round(hospdst,2))


################################ Vecinos por distancia ######################################

# Crea una nueva matriz de distancias (vec_6km) a partir de los datos de hospdst
vec_6km <- hospdst

# Establece como cero las distancias que sean mayores que seis y uno para los valores mayores que cero y menores o iguales a seis kilometros. 
vec_6km[vec_6km>6] <- 0
vec_6km[vec_6km<=6 & vec_6km>0] <- 1

# Exhibe los resultados
View(vec_6km)

# Copia los datos de la matriz de vecindad de 6km a una nueva matriz (wvec)
wvec <- vec_6km
vecs <- NA

# Genera para cada linea el valor ponderado de cada vecino en el total de vecinos
for (i in 1:nrow(vec_6km)){
  
  # Calcula el numero total de vecinos para cada hospital (linea)
  n_vec <- sum(wvec[i,])

  # Genera una variable "vecs" que contendra el numero de vecinos para todos los casos
  if (is.na(vecs)) vecs <- n_vec
  else vecs <- rbind(vecs, n_vec, deparse.level=0)

  # Divide el valor de cada columna de la linea i por el total
  wvec[i,] <- wvec[i,]/n_vec
}

# Exhibe los resultados de la matriz de vecindad
View(wvec)

# Exhibe el numero de vecinos de cada hospital
vecs

################################### Vecinos mas ####################################

# Carga el paquete spatstat, necesario para la identificacion del vecino mas cercano
library(spatstat)

# Identifica, para cada punto, su vecino mas cercano
vec_id <- nnwhich(as.ppp(hosp))     

# Identifica la distancia hasta el vecino mas cercano
vec_dist <- nndist(as.ppp(hosp))

# Genera una variable de identificacion para los hospitales
id <- seq(from=1, to=length(vec_id))

# confiere los resultados
View(data.frame(cbind(id,vec_id, vec_dist)))


############# Vecinos mas cercanos (eventos de distinto tipo) #####################

# Identifica los vecinos mas cercanos de dos tipos distintos de puntos
# En este ejemplo seran los hospitales mas cercanos a cada escuela
vec_mtype <- nncross(as.ppp(esc), as.ppp(hosp))

# Genera el mapa de los distritos de Salvador
plot(salva_dist)

# Anade las setas que conectan las escuelas a los hospitales mas cercanos
arrows(esc$lng, esc$lat, hosp$lng[vec_mtype$which], hosp$lat[vec_mtype$which], length=0.1)

# Identifica las escuelas como puntos en verde oscuro y los hospitales en rojo.
plot(esc, pch=19, col="darkgreen", cex=0.7,add=TRUE)
plot(hosp, pch=19, col="red", add=TRUE)


################## Los K-vecinos mas cercanos #####################################

# Carga el paquete spdep
library(spdep)

# Encuentra los 4 hospitales mas cercanos en km
# Parametros:
#             hosp - objeto de puntos a que se desea encontrar los vecinos
#             k=4 - define que se desea encontrar los 4 vecinos mas cercanos
#             longlat = TRUE - define que la distancia esta expresada en kilometros
knnb <- knearneigh(hosp, k=4, longlat = TRUE)

# Exhibe una lista, para cada hospital, de los cuatro vecinos mas cercanos
knnb$nn 

# Genera un mapa de conectividad entre los hospitales
coords <- coordinates(hosp)
plot(salva_dist)
plot(knn2nb(knnb), coords, col="blue", add=TRUE)
plot(hosp, pch=19, col="red", border="grey", add=TRUE)



################## Matriz de Contiguidad ##################################

# Carga el paquete spdep, necesario para la identificacion de los vecinos
library(spdep, PBSmapping)

# Genera un objeto de tipo "neighbour" conteniendo las informaciones sobre la vecindad.
# Parametros:
#             salva_dist - objeto de tipo poligono para el cual se testa la contiguidad
#             queen = TRUE - define como vecinos a todos los poligonos que se toquen entre si.
nb <- poly2nb(salva_dist, queen=TRUE) 

# Genera un informe de las caracteristicas de la matriz de contiguidad
summary(nb)

# Extrae el numero de vecinos de cada distrito de Salvador
card(nb)

# Genera una matriz de vecindad ponderada por el peso de cada vecino en el total, es decir, 
# la suma de todos los valores mayores que cero en una misma linea de la matriz es igual a 1
mat_nb <- nb2mat(nb)
View(mat_nb)

# Genera un mapa de conectividad entre los distritos
coords <- coordinates(salva_dist)
plot(salva_dist)
plot(nb, coords, col="red", lwd=2, add=TRUE)


################## Operaciones Geograficas: Interseccion, Union, Diferencia ##########################




##### diferencia #####################################################################################  

# Carga el paquete rgeos
library(rgeos)

# Abre el archivo de mapas con los sectores maritimos de Salvador
salva_mar <- readShapeSpatial("salva_mar.shp")

# Selecciona solo las islas
islas <- salva_mar[salva_mar$NM_SUBDIST=="MAR",]

# Genera los dos mapas
plot(salva_mar)
plot(islas)

# Lleva a cabo a diferencia entre los dos y crea un nuevo objeto de mapas denominado "mar", que excluye las islas
mar <- gDifference(salva_mar, islas)

# Genera el mapa del objeto "mar".
plot(mar)


##### Union #####################################################################################

# Metodo A por utilizacion de la funcion gUnion(.)

# Abre el archivo de los limites de Salvador
salva_lim <- readShapeSpatial("salvador.shp")

# Lleva a cabo la union entre las fronteras de Salvador y el mar colindante.
unionA <- gUnion(mar, salva_lim)

# Genera el mapa de los resultados
plot(unionA)

# Metodo B â utilizacion de la funcion spRbind(.)

# Cambia el ID del poligono para A (pues los limites de los dos objetos no pueden tener el mismo ID)
mar <- spChFIDs(mar, "A")

# Lleva a cabo la union de los dos objetos (sin fusionarlos por completo)
unionB <- spRbind(salva_lim,mar)

# Genera el mapa de los resultados
plot(unionB)


##### Interseccion #########################################################################

# Abre el archivo de los poligonos de Voronoi de los hospitales de Salvador
sp_voronoi <- readShapeSpatial("sp_voronoi.shp")

# Genera el mapa superpuesto de los limites de Salvador y del diagrama de Voronoi 
plot(salva_lim)
plot(sp_voronoi, add=TRUE)
plot(hosp, pch=19, col="red", cex=0.8, add=TRUE)

# Convierte los limites del municipio de Salvador y el Voronoi a un PolySet 
salva.ps <- SpatialPolygons2PolySet(salva_lim)
voro.ps <- SpatialPolygons2PolySet(sp_voronoi)

# Lleva a cabo la interseccion entre el diagrama de Voronoi y las fronteras de Salvador
voro.ps <- joinPolys(voro.ps, salva.ps, operation="INT")

# Convierte los resultados en un objeto Spatial Polygons
voro_sppoly <- PolySet2SpatialPolygons(voro.ps, close_polys=TRUE)

# Genera una representacion visual de la operacion
plot(voro_sppoly)
plot(hosp, pch=19, col="red", cex=0.8, add=TRUE)




############################### Analisis de patrones de puntos #####################################


##### Densidad de Kernel ################################################

# Carga el paquete spatstat
library(spatstat)

# Crea una ventana de observacion con las fronteras del municipio de Salvador
spatstat.options(checkpolygons=FALSE)
wsalva <- as.owin(salva_dist)
spatstat.options(checkpolygons=TRUE)

# Genera un objeto de puntos con las escuelas dentro de la ventana de observacion creada anteriormente 
p_esc <- ppp(esc$lng, esc$lat, window=wsalva)

# Genera la densidad de los puntos para las escuelas de Salvador
dens_esc <- density.ppp(p_esc, 0.01, diggle=TRUE, edge=TRUE, dimyx=648)

# Define una escala progresiva de colores calientes con 100 gradaciones
colores <- heat.colors(100)

# Genera el mapa del limite de Salvador
plot(salva_lim)

# Genera el mapa isopletico de los resultados
plot(dens_esc, col=colores[100:1], add=TRUE)

# Superpone las fronteras de los distritos de Salvador
plot(salva_dist, add=TRUE)

# Nota: la funcion persp.im(.) permite generar el mismo mapa en 3D, representando la densidad como elevacion.
par(mar=c(2,2,2,0.1))
persp.im(dens_esc, colmap=topo.colors(100), theta = 30, phi = 40, main= "Densidad de escuelas (Salvador)", zlab="Densidad", xlab="longitud", ylab="latitud")



##### Focos de incidencia #################################################


# Genera el mapa con los distritos de Salvador
plot(salva_lim)

# La funcion Sharpen(.) lleva a cabo la identificacion de los  focos de concentracion
# Parametros:
#  	as.ppp(esc) es el objeto de puntos de las escuelas convertido a un tipo ppp
sharp <- sharpen(as.ppp(esc))

# Mapea los focos de incidencia
plot(sharp, bg="red", fg="transparent", main="", bty="n", add=TRUE)

# Genera el mapa de puntos con las escuelas
plot(esc, pch=19, col="darkgreen", cex=0.6, add=TRUE)

# Sobrepone el mapa con los distritos
plot(salva_dist, add=TRUE)

     
##### Regiones de interes #####################################


# Carga el paquete tripack, necesario para la creacion de las regiones de interes
library(tripack)

# Lleva a cabo la triangulacion de Delauney para los tres tipos de equipo 
coord <- coordinates(hosp)
tri_hosp <- tri.mesh(coord[,1],coord[,2], duplicate = "remove")

coord_esc <- coordinates(esc)
tri_esc <- tri.mesh(coord_esc[,1],coord_esc[,2], duplicate = "remove")

coord_comi <- coordinates(comi)
tri_comi <- tri.mesh(coord_comi[,1],coord_comi[,2], duplicate = "remove")

# Genera el mapa de los distritos de Salvador
plot(salva_lim)

# mapea las regiones de interes de cada uno.
convex.hull(tri_hosp, plot.it=TRUE, col="red", add=TRUE, lwd=2)
convex.hull(tri_esc, plot.it=TRUE, col="darkgreen", add=TRUE, lwd=2)
convex.hull(tri_comi, plot.it=TRUE, col="blue", add=TRUE, lwd=2)

# Anade una leyenda al mapa que identifica cada tipo de punto
legend("bottomright", c("Escuelas","Hospitales","Comisarias"), border="transparent", pch="|", col=c("darkgreen","red","blue"), bty="n", cex=1.2, pt.lwd=2)




##### Diagrama de Voronoi ###########################################

# recorta por las fronteras del contexto en que se encuentra (municipio de Salvador) y luego reconvierte en un objeto SpatialPolygon

# Carga el paquete PBSmapping, necesario para las operaciones geograficas deseadas
library(PBSmapping)

# Extrae las coordinadas de los hospitales de Salvador
coord <- data.frame(coordinates(hosp))
names(coord) <- c("X","Y")

# Calcula el diagrama de Voronoi
bb_salva <- bbox(salva_lim)
voro <- calcVoronoi(coord, xlim=bb_salva[1,], ylim=bb_salva[2,])

# Convierte los resultados en un PolySet y le confiere la projeccion "UTM" y la zona 24, donde se encuentra Salvador de Bahia
voro.ps <- as.PolySet(voro, projection = "UTM", zone ="24")

# Convierte los limites del municipios de Salvador a un PolySet 
salva <- SpatialPolygons2PolySet(salva_lim)

# Lleva a cabo la interseccion entre el diagrama de Voronoi y las fronteras de Salvador
voro.ps <- joinPolys(voro.ps, salva, operation="INT")

# Convierte los resultados en un objeto Spatial Polygons
voro_sppoly <- PolySet2SpatialPolygons(voro.ps, close_polys=TRUE)

# Genera una representacion visual de la operacion
plot(voro_sppoly)
plot(hosp, pch=19, col="red", cex=0.8, add=TRUE)


##########################################################################################




#################### Guardar y Exportar los resultados ###################################


##### Lee datos de tipo KML desde el Google Earth ##### 

# carga el paquete rgdal
library(rgdal)

## Lista todos los formatos a que se puede exportar los resultados
ogrDrivers()

# Funcion readOGR(.), lee el archivo de tipo KML
# Parametros:
#           "salva_cine.kml" - nombre del archivo kml a ser importado
#           "Cines_Salvador" - nombre de la capa (layer) utilizada por el archivo en el Google Earth
salva_cines <- readOGR(dsn="salva_cine.kml", layer="Cines_Salvador")

# Genera un mapa de los resultados
plot(salva_dist)
plot(salva_cines, pch=19, col="red", add=TRUE)


##### Guarda en el formato del Google Earth #####


# Carga el paquete rgdal
library(rgdal)

# Convierte la proyeccion del objeto a una lat-long compatible con Google Earth
salva_kml <- salva_dist
proj4string(salva_kml) <- CRS("+proj=longlat")

# Guarda el archivo con el nombre "salva_dist.kml".
writeOGR(salva_kml, dsn="salva_dist.kml", layer="distritos", driver="KML", overwrite_layer=TRUE)




##### MapInfo #####

# Guarda los distritos en el formato MapInfo
writeOGR(salva_dist, dsn="c:/CIS/Material Auxiliar/Shapes", layer="salva_dist", driver="MapInfo File", dataset_options="FORMAT=MIF")

# Lee los resultados desde el MapInfo
mif <- readOGR(dsn="salva_dist.mif", layer="salva_dist")



##### ESRI Shapefile #####


# Carga el paquete maptools
library(maptools)

# Abre el archivo en el R a modo mas sencillo 
salva_dist <- readShapeSpatial("salva_dist.shp")

# Guarda los resultados en el archivo
writeSpatialShape(salva_dist, "salva_dist2.shp")


###############################################################################
############ FINAL DEL ARCHIVO DE EJEMPLOS - CAPITULO 4 #######################
###############################################################################



